@@ -40,7 +40,7 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 # The prototyping gives List::BinarySearch a similar feel to List::Util,
 # and List::MoreUtils.
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 # Needed for developer's releases: See perlmodstyle.
 # $VERSION = eval $VERSION;    ## no critic (eval,version)
@@ -125,7 +125,7 @@ Examples:
     # Find the lowest index of a matching element, or best insert point.
 
     $index = binsearch_pos {$a cmp $b} 'Chopin', @str_array;  # Insert at [3].
-    $index = binsearch_pos 600, @num_array;                   # Insert at [5].
+    $index = binsearch_pos {$a <=> $b} 600, @num_array;       # Insert at [5].
 
     splice @num_array, $index, 0, 600
       if( $num_array[$index] != 600 );                        # Insertion at [5]
